/* 
 * Copyright (C) 1999 JP Rosevear
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#include <gnome.h>

#define MENU_SIZE		19

#define MENU_NEW		0
#define MENU_LOAD		1
#define MENU_SAVE		2
#define MENU_SERVERS		3
#define MENU_FLAG		4
#define MENU_DRAW		5
#define MENU_RESIGN		6
#define MENU_START		7
#define MENU_NEXT		8
#define MENU_PREVIOUS		9
#define MENU_END		10
#define MENU_TAKEBACK		11
#define MENU_NOW		12
#define MENU_GO			13
#define MENU_CWHITE		14
#define MENU_CBLACK		15
#define MENU_TWOP		16
#define MENU_ANALYZE	17
#define MENU_LEVEL		18

void create_menus(void);
void check_menu(gint item);
void uncheck_menu(gint item);
void uncheck_all_menus(void);
void enable_menu(gint item);
void enable_all_menus(void);
void disable_menu(gint item);
void disable_all_menus(void);

void menu_new_cb (GtkWidget *widget, void *data);
void menu_load_cb (GtkWidget *widget, void *data);
void menu_save_cb (GtkWidget *widget, void *data);
void server_cb (GtkWidget *widget, void *data);
void menu_quit_cb (GtkWidget *widget, void *data);
void menu_flag_cb (GtkWidget *widget, void *data);
void menu_draw_cb (GtkWidget *widget, void *data);
void menu_resign_cb (GtkWidget *widget, void *data);
void menu_start_cb (GtkWidget *widget, void *data);
void menu_previous_cb (GtkWidget *widget, void *data);
void menu_next_cb (GtkWidget *widget, void *data);
void menu_end_cb (GtkWidget *widget, void *data);
void menu_takeback_cb (GtkWidget *widget, void *data);
void menu_now_cb (GtkWidget *widget, void *data);
void menu_go_cb (GtkWidget *widget, void *data);
void menu_new_cb (GtkWidget *widget, void *data);
void menu_computer_white_cb (GtkWidget *widget, void *data);
void menu_computer_black_cb (GtkWidget *widget, void *data);
void menu_two_players_cb (GtkWidget *widget, void *data);
void menu_analyse_mode_cb (GtkWidget *widget, void *data);
void level_cb (GtkWidget *widget, void *data);
void menu_prefs_cb (GtkWidget *widget, void *data);
void menu_about_cb (GtkWidget *widget, void *data);

void command_cb (GtkWidget *widget, void *data);
